@@ -46,13 +46,6 @@ namespace Headers
 
 class BasePrivate;
 
-enum contentCategory {
-    CCsingle,
-    CCcontainer,
-    CCmixedPart,
-    CCalternativePart
-};
-
 /**
   Various possible values for the "Content-Transfer-Encoding" header.
 */
@@ -1117,11 +1110,6 @@ public:
     */
     void setPartialParams(int total, int number);
 
-    // TODO: document
-    contentCategory category() const;
-
-    void setCategory(contentCategory c);
-
 protected:
     bool parse(const char *&scursor, const char *const send, bool isCRLF = false) override;
 
